==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sq\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  "Artikull Inventari"
 ,"Artikuj Inventari"

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""

]
, "Name"
: "Emri"

, "Status"
: "Statusi"

, "Inventory ID"
: "ID Inventari"

, "Description"
: "Përshkrimi"

, "Location"
: "Vendndodhja"

, "Invoice date"
: "Data e Faturës"

, "Invoice"
: "Faturë"

, "Price"
: "Çmimi"

, "Cost Center"
: ""

, "Warranty"
: "Garancia"

, "Item added"
: "Artikull i  shtuar"

, "Item removed"
: "Artikull i hequr"

, "Deprecate"
: ""

, "The active number must be less than or equal total number."
: "Numëri aktiv duhet të jetë më i vogël ose i barabartë."

, "General"
: "I Përgjithshëm"

, "ID"
: "ID"

, "Enter description"
: "Vendosni përshkrimin"

, "Added"
: "Shtuar"

, "Removed"
: "Hequr"

, "Total number"
: "Numri total"

, "Available number"
: "Numri i disponueshëm"

, "Accounting"
: "Llogaritje"

, "Cost center"
: ""

, "Depreciate"
: "Zhvlerëso"

, "Default Inventory Item Container"
: "Kontenieri i paracaktuar i artikujve te inventarit"

, "The default container for new items"
: "Kontenieri i paracaktuar për artikujt e rinj"

, "Inventory Status Available"
: "Statusi i mundshëm i inventarit"

, "Possible status."
: "Statusi i mundshëm"

, "ordered"
: "porositur"

, "available"
: "i mundshëm"

, "defect"
: "difektoz"

, "missing"
: "mungon"

, "removed"
: "hequr"

, "unknown"
: "i/e panjohur"

, "Inventory CSV import"
: "Import CSV i inventarit"

, "Import list (###CURRENTDATE###)"
: "importo listen (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Artikuj të importuar në ###CURRENTDATE### më ###CURRENTTIME### nga ###USERFULLNAME###"

, "All Inventory Items"
: "Të gjithë Artikujt e inventarit"

, "All existing Inventory Items"
: "Të gjithë Artikujt egzistues të inventarit"

, "Inventory"
: "Inventari"

, "Inventory item"
: "Artikull Inventari"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.03.4.tar.bz2: Inventory/js/Inventory-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: "Kontenieri i paracaktuar i artikujve te inventarit"

, "The default container for new items"
: "Kontenieri i paracaktuar për artikujt e rinj"

, "The active number must be less than or equal total number."
: "Numëri aktiv duhet të jetë më i vogël ose i barabartë."

, "General"
: "I Përgjithshëm"

, "ID"
: "ID"

, "Name"
: "Emri"

, "Description"
: "Përshkrimi"

, "Enter description"
: "Vendosni përshkrimin"

, "Location"
: "Vendndodhja"

, "Added"
: "Shtuar"

, "Warranty"
: "Garancia"

, "Removed"
: "Hequr"

, "Total number"
: "Numri total"

, "Available number"
: "Numri i disponueshëm"

, "Status"
: "Statusi"

, "Accounting"
: "Llogaritje"

, "Price"
: "Çmimi"

, "Cost center"
: ""

, "Invoice"
: "Faturë"

, "Invoice date"
: "Data e Faturës"

, "Depreciate"
: "Zhvlerëso"

, "All Inventory Items"
: "Të gjithë Artikujt e inventarit"

, "All existing Inventory Items"
: "Të gjithë Artikujt egzistues të inventarit"

, "Inventory"
: "Inventari"

, "Inventory Status Available"
: "Statusi i mundshëm i inventarit"

, "Possible status."
: "Statusi i mundshëm"

, "ordered"
: "porositur"

, "available"
: "i mundshëm"

, "defect"
: "difektoz"

, "missing"
: "mungon"

, "removed"
: "hequr"

, "unknown"
: "i/e panjohur"

, "Inventory item, Inventory items"
: [
  "Artikull Inventari"
 ,"Artikuj Inventari"

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""

]
, "Inventory ID"
: "ID Inventari"

, "Cost Center"
: ""

, "Item added"
: "Artikull i  shtuar"

, "Item removed"
: "Artikull i hequr"

, "Inventory CSV import"
: "Import CSV i inventarit"

, "Import list (###CURRENTDATE###)"
: "importo listen (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Artikuj të importuar në ###CURRENTDATE### më ###CURRENTTIME### nga ###USERFULLNAME###"

, "Inventory item"
: "Artikull Inventari"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
